%define anolis_release 1

Name:           openal-soft
Version:        1.23.0
Release:        %{anolis_release}%{?dist}
Summary:        Open Audio Library

License:        LGPL-2.0-or-later AND BSD-3-Clause
URL:            https://openal-soft.org/
Source0:        https://openal-soft.org/openal-releases/openal-soft-%{version}.tar.bz2

BuildRequires:  alsa-lib-devel
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  ninja-build
BuildRequires:  pipewire-devel
BuildRequires:  libmysofa-devel
BuildRequires:  libsndfile-devel
BuildRequires:  pulseaudio-libs-devel
BuildRequires:  qt5-qtbase-devel
BuildRequires:  SDL2-devel
Obsoletes:      openal <= 0.0.10
Provides:       openal = %{version}

%description
OpenAL Soft is a cross-platform software implementation of the OpenAL 3D
audio API. It's built off of the open-sourced Windows version available
originally from the SVN repository at openal.org. OpenAL provides
capabilities for playing audio in a virtual 3d environment. Distance
attenuation, doppler shift, and directional sound emitters are among
the features handled by the API. More advanced effects, including air
absorption, low-pass filters, and reverb, are available through the
EFX extension. It also facilitates streaming audio, multi-channel buffers,
and audio capture.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Obsoletes:      openal-devel <= 0.0.10
Provides:       openal-devel = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        examples
Summary:        Sample applications for OpenAl Soft
Requires:       %{name} = %{version}-%{release}

%description	examples
Sample applications for OpenAl Soft.

%package        qt
Summary:        Qt frontend for configuring OpenAL Soft
Requires:       %{name} = %{version}-%{release}

%description    qt
The %{name}-qt package contains alsoft-config, a Qt-based tool
for configuring OpenAL features.

%package        doc
Summary:        Doc files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
Doc files for %{name}

%prep
%autosetup -p1

%build
%cmake -G Ninja \
    -DCMAKE_BUILD_TYPE=Release \
    -DALSOFT_CPUEXT_NEON:BOOL=OFF \
    -DALSOFT_EXAMPLES:BOOL=ON \
    -DALSOFT_UTILS:BOOL=ON \
    -DALSOFT_INSTALL_CONFIG:BOOL=ON \
    -DALSOFT_INSTALL_EXAMPLES:BOOL=ON \
    -DALSOFT_INSTALL_HRTF_DATA:BOOL=ON \
    -DALSOFT_INSTALL_UTILS:BOOL=ON
%cmake_build

%install
%cmake_install

install -Dpm644 alsoftrc.sample %{buildroot}%{_sysconfdir}/openal/alsoft.conf
# Don't pin the pulseaudio stream to a specific output device
sed -i 's/#allow-moves = false/allow-moves = true/' \
  %{buildroot}%{_sysconfdir}/openal/alsoft.conf

%generate_compatibility_deps

%files
%license COPYING BSD-3Clause
%{_bindir}/openal-info
%{_libdir}/libopenal.so.*
%dir %{_sysconfdir}/openal
%config(noreplace) %{_sysconfdir}/openal/alsoft.conf
%{_datadir}/openal
%exclude %{_datadir}/openal/alsoftrc.sample
%exclude %{_datadir}/openal/presets/presets.txt
%dir %{abidir}
%{abidir}/*.dump
%{abidir}/openal-info-option.list

%files devel
%{_bindir}/makemhr
%{_includedir}/*
%{_libdir}/libopenal.so
%{_libdir}/pkgconfig/openal.pc
%{_libdir}/cmake/OpenAL
%{abidir}/makemhr-option.list

%files examples
%{_bindir}/alhrtf
%{_bindir}/allatency
%{_bindir}/alloopback
%{_bindir}/almultireverb
%{_bindir}/alplay
%{_bindir}/alreverb
%{_bindir}/alstream
%{_bindir}/alrecord
%{_bindir}/altonegen
%{abidir}/alrecord-option.list

%files qt
%{_bindir}/alsoft-config

%files doc
%doc README.md ChangeLog

%changelog
* Thu Mar 16 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.23.0-1
- init from upstream
